@@ -53,7 +53,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static int selection_table_signals[LAST_SIGNAL] = { 0 };
+static guint selection_table_signals[LAST_SIGNAL] = { 0 };
 
 #define BLUETOOTH_CHOOSER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), \
 									BLUETOOTH_TYPE_CHOOSER, BluetoothChooserPrivate))
@@ -121,7 +121,7 @@ connected_to_icon (GtkTreeViewColumn *column, GtkCellRenderer *cell,
 
 	gtk_tree_model_get (model, iter, BLUETOOTH_COLUMN_CONNECTED, &connected, -1);
 
-	g_object_set (cell, "icon-name", connected ? GTK_STOCK_CONNECT : NULL, NULL);
+	g_object_set (cell, "icon-name", connected ? "gtk-connected" : NULL, NULL);
 }
 
 static void
@@ -177,7 +177,7 @@ set_search_label (BluetoothChooser *self, gboolean state)
 	} else {
 		gtk_widget_show (priv->spinner);
 		gtk_spinner_start (GTK_SPINNER (priv->spinner));
-		gtk_label_set_text (GTK_LABEL (priv->search_label), _("Searching for devices..."));
+		gtk_label_set_text (GTK_LABEL (priv->search_label), _("Searching for devices…"));
 	}
 }
 
@@ -801,7 +801,7 @@ bluetooth_chooser_init(BluetoothChooser *self)
 	priv->spinner = gtk_spinner_new ();
 	gtk_container_add (GTK_CONTAINER (hbox), priv->spinner);
 	gtk_widget_show (priv->spinner);
-	priv->search_label = gtk_label_new (_("Searching for devices..."));
+	priv->search_label = gtk_label_new (_("Searching for devices…"));
 	gtk_container_add (GTK_CONTAINER (hbox), priv->search_label);
 	gtk_widget_show (priv->search_label);
 	gtk_widget_show (hbox);
